/**
 * @file entity collection field behavior.
 *
 */

(function ($, Drupal) {

  "use strict";

  Drupal.behaviors.entityCollectionfieldBehavior = {
    attach: function (context, settings) {
      $('body').once('entityCollectionTriggers')
          .on('activatedEntityCollection', Drupal.behaviors.entityCollectionfieldBehavior.refreshCollectionBlocks)
          .on('activatedEntityCollection', Drupal.behaviors.entityCollectionfieldBehavior.refreshAllCollectionActions)
          .on('addEntityToCollection', Drupal.behaviors.entityCollectionfieldBehavior.refreshCollectionBlocks)
          .on('removeEntityFromCollection', Drupal.behaviors.entityCollectionfieldBehavior.refreshCollectionBlocks);
    },
    refreshCollectionBlocks: function (event, entityCollectionBundle, entityCollectionId, entityId) {
      $('.js-entity-collection-block').each(function () {
        if ($(this).attr('data-entity-collection-type') === entityCollectionBundle) {
          var element_settings = {};
          element_settings.progress = {type: 'throbber'};
          element_settings.url = '/ajax/entity-collector/block/' + $(this).attr('id');
          element_settings.base = $(this).attr('id');
          element_settings.element = this;
          Drupal.ajax(element_settings).execute();
        }
      });
    },
    refreshAllCollectionActions: function (event, entityCollectionBundle) {
      var removeSelector = '.js-entity-collection-action-remove.entity-collection-type-' + entityCollectionBundle;
      var addSelector = '.js-entity-collection-action-add.entity-collection-type-' + entityCollectionBundle;

      $(removeSelector + ',' + addSelector).each(Drupal.behaviors.entityCollectionfieldBehavior.refreshCollectionAction);
    },
    refreshCollectionAction: function () {
      var element = $(this);
      var baseurl = element.attr("data-base-url");
      var entityId = element.attr("data-entity");
      var entityCollection = element.attr("data-entity-collection");
      var href = baseurl + '/' + entityCollection + '/' + entityId;
      var id = '#' + element.attr('id');
      element.attr("href", href);

      for (var indexInstance in Drupal.ajax.instances) {
        var instance = Drupal.ajax.instances[indexInstance];
        if (instance === undefined || instance.selector !== id) {
          continue;
        }

        instance.options.url = href;
        break;
      }

    }
  };

})(jQuery, Drupal);