<?php

namespace Drupal\entity_collector;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the Entity collection entity.
 *
 * @see \Drupal\entity_collector\Entity\EntityCollection.
 */
class EntityCollectionAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\entity_collector\Entity\EntityCollectionInterface $entity */
    $is_participant = in_array($account->id(), $entity->getParticipantsIds());
    $is_owner = $account->id() == $entity->getOwnerId();

    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished entity collection entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'view published entity collection entities')->andIf(AccessResult::allowedIf($is_owner || $is_participant));

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit entity collection entities')->andIf(AccessResult::allowedIf($is_owner || $is_participant));

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete entity collection entities')->andIf(AccessResult::allowedIf($is_owner));
    }

    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add entity collection entities');
  }
}
